<?php

namespace Suresh\University\Policies;

use Litepie\User\Contracts\UserPolicy;
use Suresh\University\Models\University;

class UniversityPolicy
{

    /**
     * Determine if the given user can view the university.
     *
     * @param UserPolicy $user
     * @param University $university
     *
     * @return bool
     */
    public function view(UserPolicy $user, University $university)
    {
        if ($user->canDo('university.university.view') && $user->isAdmin()) {
            return true;
        }

        return $university->user_id == user_id() && $university->user_type == user_type();
    }

    /**
     * Determine if the given user can create a university.
     *
     * @param UserPolicy $user
     * @param University $university
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('university.university.create');
    }

    /**
     * Determine if the given user can update the given university.
     *
     * @param UserPolicy $user
     * @param University $university
     *
     * @return bool
     */
    public function update(UserPolicy $user, University $university)
    {
        if ($user->canDo('university.university.update') && $user->isAdmin()) {
            return true;
        }

        return $university->user_id == user_id() && $university->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given university.
     *
     * @param UserPolicy $user
     * @param University $university
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, University $university)
    {
        return $university->user_id == user_id() && $university->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given university.
     *
     * @param UserPolicy $user
     * @param University $university
     *
     * @return bool
     */
    public function verify(UserPolicy $user, University $university)
    {
        if ($user->canDo('university.university.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given university.
     *
     * @param UserPolicy $user
     * @param University $university
     *
     * @return bool
     */
    public function approve(UserPolicy $user, University $university)
    {
        if ($user->canDo('university.university.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
